@@ -6,7 +6,7 @@ from vkbottle_types.responses import base, pages
 class PagesCategory(BaseCategory):
     async def clear_cache(
         self, url: str, **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Allows to clear the cache of particular 'external' pages which may be attached to VK posts.
         :param url: Address of the page where you need to refesh the cached version
         """
@@ -26,7 +26,7 @@ class PagesCategory(BaseCategory):
         need_source: typing.Optional[bool] = None,
         need_html: typing.Optional[bool] = None,
         **kwargs
-    ) -> pages.GetResponseModel:
+    ) -> pages.PagesWikipageFull:
         """Returns information about a wiki page.
         :param owner_id: Page owner ID.
         :param page_id: Wiki page ID.
@@ -48,7 +48,7 @@ class PagesCategory(BaseCategory):
         group_id: typing.Optional[int] = None,
         user_id: typing.Optional[int] = None,
         **kwargs
-    ) -> pages.GetHistoryResponseModel:
+    ) -> typing.List[pages.PagesWikipageHistory]:
         """Returns a list of all previous versions of a wiki page.
         :param page_id: Wiki page ID.
         :param group_id: ID of the community that owns the wiki page.
@@ -62,7 +62,7 @@ class PagesCategory(BaseCategory):
 
     async def get_titles(
         self, group_id: typing.Optional[int] = None, **kwargs
-    ) -> pages.GetTitlesResponseModel:
+    ) -> typing.List[pages.PagesWikipage]:
         """Returns a list of wiki pages in a group.
         :param group_id: ID of the community that owns the wiki page.
         """
@@ -79,7 +79,7 @@ class PagesCategory(BaseCategory):
         user_id: typing.Optional[int] = None,
         need_html: typing.Optional[bool] = None,
         **kwargs
-    ) -> pages.GetVersionResponseModel:
+    ) -> pages.PagesWikipageFull:
         """Returns the text of one of the previous versions of a wiki page.
         :param version_id:
         :param group_id: ID of the community that owns the wiki page.
@@ -94,7 +94,7 @@ class PagesCategory(BaseCategory):
 
     async def parse_wiki(
         self, text: str, group_id: typing.Optional[int] = None, **kwargs
-    ) -> pages.ParseWikiResponseModel:
+    ) -> str:
         """Returns HTML representation of the wiki markup.
         :param text: Text of the wiki page.
         :param group_id: ID of the group in the context of which this markup is interpreted.
@@ -113,7 +113,7 @@ class PagesCategory(BaseCategory):
         user_id: typing.Optional[int] = None,
         title: typing.Optional[str] = None,
         **kwargs
-    ) -> pages.SaveResponseModel:
+    ) -> int:
         """Saves the text of a wiki page.
         :param text: Text of the wiki page in wiki-format.
         :param page_id: Wiki page ID. The 'title' parameter can be passed instead of 'pid'.
@@ -135,7 +135,7 @@ class PagesCategory(BaseCategory):
         view: typing.Optional[int] = None,
         edit: typing.Optional[int] = None,
         **kwargs
-    ) -> pages.SaveAccessResponseModel:
+    ) -> int:
         """Saves modified read and edit access settings for a wiki page.
         :param page_id: Wiki page ID.
         :param group_id: ID of the community that owns the wiki page.
